# Generated by roxygen2: do not edit by hand

export("%>%")
export("%notin%")
export(bromeliad_inverts_measurements)
export(data_checker)
export(dry_wet)
export(full_estimation_table)
export(hellometry)
export(make_measurement_table)
export(make_trait_table)
export(matcher_of_traits)
export(predict_biomass)
export(r_squared)
export(trini_communities)
importFrom(dplyr,group_by)
importFrom(dplyr,n)
importFrom(dplyr,ntile)
importFrom(dplyr,row_number)
importFrom(dplyr,summarise)
importFrom(magrittr,"%>%")
importFrom(purrr,imap)
importFrom(rlang,.data)
importFrom(rlang,.env)
importFrom(rlang,expr)
importFrom(rlang,sym)
importFrom(rlang,syms)
importFrom(stats,df.residual)
importFrom(stats,glm)
importFrom(stats,lm)
importFrom(stats,poisson)
importFrom(stats,predict)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(tidyselect,all_of)
