# hellometry

Estimates body size and biomass of organisms from allometric
relationships. `hellometry` works with any dataset that follows a few simple
column-naming conventions, using the measurements you supply to impute the ones
that are missing.

To download the package, run `devtools::install_github("pierrerogy/hellometry", build_vignettes = TRUE)`. The package vignette (`vignette("hellometry")`) contains a worked example, and additional details.
