% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/make_trait_table.R
\name{make_trait_table}
\alias{make_trait_table}
\title{Prepare data to do estimation with traits in \code{full_estimation_table}}
\usage{
make_trait_table(measurement_table, trait_columns, id_col = "species")
}
\arguments{
\item{measurement_table}{A table with the numerical measurements and biomass
used to compute allometric lms}

\item{trait_columns}{List of traits to match, should be column names in measurement_table}

\item{id_col}{Name of the column holding a unique identifier per species/taxon.
Default "species".}
}
\value{
List of tibbles, one per trait grouping, each carrying the
measurements of the species sharing that grouping's traits
}
\description{
Remove columns with taxonomy, and replace them with trait-based groupings
}
\examples{
# Fuzzy traits of three species, sp_a and sp_b within +/- 1 of each other
measurement_table <-
  data.frame(species = rep(c("sp_a", "sp_b", "sp_c"), each = 4),
             stage = "larva",
             size_col = c(1, 2, 3, 4, 1.2, 2.1, 3.3, 4.2, 8, 9, 10, 11),
             biomass_col = c(0.1, 0.4, 1, 2, 0.2, 0.5, 1.1, 2.2, 12, 15, 20, 26),
             AS1 = rep(c(1, 2, 5), each = 4),
             AS2 = rep(c(3, 3, 9), each = 4))

# The measurements of the species sharing each trait grouping
make_trait_table(measurement_table, trait_columns = c("AS1", "AS2"))
}
